@@ -16,6 +16,7 @@ from __future__ import absolute_import
 import logging
 import os
 import platform
+from datetime import datetime
 
 import boto3
 from botocore.exceptions import ClientError
@@ -29,6 +30,7 @@ from sagemaker.local.entities import (
     _LocalProcessingJob,
     _LocalTrainingJob,
     _LocalTransformJob,
+    _LocalPipeline,
 )
 from sagemaker.session import Session
 from sagemaker.utils import get_config_value, _module_import_error
@@ -36,7 +38,7 @@ from sagemaker.utils import get_config_value, _module_import_error
 logger = logging.getLogger(__name__)
 
 
-class LocalSagemakerClient(object):
+class LocalSagemakerClient(object):  # pylint: disable=too-many-public-methods
     """A SageMakerClient that implements the API calls locally.
 
     Used for doing local training and hosting local endpoints. It still needs access to
@@ -56,6 +58,7 @@ class LocalSagemakerClient(object):
     _models = {}
     _endpoint_configs = {}
     _endpoints = {}
+    _pipelines = {}
 
     def __init__(self, sagemaker_session=None):
         """Initialize a LocalSageMakerClient.
@@ -402,6 +405,110 @@ class LocalSagemakerClient(object):
         if ModelName in LocalSagemakerClient._models:
             del LocalSagemakerClient._models[ModelName]
 
+    def create_pipeline(
+        self, pipeline, pipeline_description, **kwargs  # pylint: disable=unused-argument
+    ):
+        """Create a local pipeline.
+
+        Args:
+            pipeline (Pipeline): Pipeline object
+            pipeline_description (str): Description of the pipeline
+
+        Returns:
+            Pipeline metadata (PipelineArn)
+
+        """
+        local_pipeline = _LocalPipeline(
+            pipeline=pipeline,
+            pipeline_description=pipeline_description,
+            local_session=self.sagemaker_session,
+        )
+        LocalSagemakerClient._pipelines[pipeline.name] = local_pipeline
+        return {"PipelineArn": pipeline.name}
+
+    def update_pipeline(
+        self, pipeline, pipeline_description, **kwargs  # pylint: disable=unused-argument
+    ):
+        """Update a local pipeline.
+
+        Args:
+            pipeline (Pipeline): Pipeline object
+            pipeline_description (str): Description of the pipeline
+
+        Returns:
+            Pipeline metadata (PipelineArn)
+
+        """
+        if pipeline.name not in LocalSagemakerClient._pipelines:
+            error_response = {
+                "Error": {
+                    "Code": "ResourceNotFound",
+                    "Message": "Pipeline {} does not exist".format(pipeline.name),
+                }
+            }
+            raise ClientError(error_response, "update_pipeline")
+        LocalSagemakerClient._pipelines[pipeline.name].pipeline_description = pipeline_description
+        LocalSagemakerClient._pipelines[pipeline.name].pipeline = pipeline
+        LocalSagemakerClient._pipelines[
+            pipeline.name
+        ].last_modified_time = datetime.now().timestamp()
+        return {"PipelineArn": pipeline.name}
+
+    def describe_pipeline(self, PipelineName):
+        """Describe the pipeline.
+
+        Args:
+          PipelineName (str):
+
+        Returns:
+            Pipeline metadata (PipelineArn, PipelineDefinition, LastModifiedTime, etc)
+
+        """
+        if PipelineName not in LocalSagemakerClient._pipelines:
+            error_response = {
+                "Error": {
+                    "Code": "ResourceNotFound",
+                    "Message": "Pipeline {} does not exist".format(PipelineName),
+                }
+            }
+            raise ClientError(error_response, "describe_pipeline")
+        return LocalSagemakerClient._pipelines[PipelineName].describe()
+
+    def delete_pipeline(self, PipelineName):
+        """Delete the local pipeline.
+
+        Args:
+          PipelineName (str):
+
+        Returns:
+            Pipeline metadata (PipelineArn)
+
+        """
+        if PipelineName in LocalSagemakerClient._pipelines:
+            del LocalSagemakerClient._pipelines[PipelineName]
+        return {"PipelineArn": PipelineName}
+
+    def start_pipeline_execution(self, PipelineName, **kwargs):
+        """Start the pipeline.
+
+        Args:
+          PipelineName (str):
+
+        Returns: _LocalPipelineExecution object
+
+        """
+        if "ParallelismConfiguration" in kwargs:
+            logger.warning("Parallelism configuration is not supported in local mode.")
+        if PipelineName not in LocalSagemakerClient._pipelines:
+            error_response = {
+                "Error": {
+                    "Code": "ResourceNotFound",
+                    "Message": "Pipeline {} does not exist".format(PipelineName),
+                }
+            }
+            raise ClientError(error_response, "start_pipeline_execution")
+        return LocalSagemakerClient._pipelines[PipelineName].start(**kwargs)
+
 
 class LocalSagemakerRuntimeClient(object):
     """A SageMaker Runtime client that calls a local endpoint only."""
@@ -491,7 +598,9 @@ class LocalSession(Session):
     :class:`~sagemaker.session.Session`.
     """
 
-    def __init__(self, boto_session=None, s3_endpoint_url=None, disable_local_code=False):
+    def __init__(
+        self, boto_session=None, default_bucket=None, s3_endpoint_url=None, disable_local_code=False
+    ):
         """Create a Local SageMaker Session.
 
         Args:
@@ -510,7 +619,7 @@ class LocalSession(Session):
         # discourage external use:
         self._disable_local_code = disable_local_code
 
-        super(LocalSession, self).__init__(boto_session)
+        super(LocalSession, self).__init__(boto_session=boto_session, default_bucket=default_bucket)
 
         if platform.system() == "Windows":
             logger.warning("Windows Support for Local Mode is Experimental")
@@ -535,7 +644,6 @@ class LocalSession(Session):
         else:
             self.boto_session = boto_session
 
-        # self.boto_session = boto_session or boto3.Session()
         self._region_name = self.boto_session.region_name
 
         if self._region_name is None:
@@ -559,7 +667,7 @@ class LocalSession(Session):
                 logger.error(_module_import_error("yaml", "Local mode", "local"))
                 raise e
 
-            self.config = yaml.load(open(sagemaker_config_file, "r"))
+            self.config = yaml.safe_load(open(sagemaker_config_file, "r"))
             if self._disable_local_code and "local" in self.config:
                 self.config["local"]["local_code"] = False
 
