@@ -16,8 +16,10 @@ from sagemaker.model_card.model_card import (  # noqa: F401 # pylint: disable=un
     Environment,
     ModelOverview,
     IntendedUses,
+    BusinessDetails,
     ObjectiveFunction,
     TrainingMetric,
+    HyperParameter,
     Metric,
     Function,
     TrainingJobDetails,
